@@ -89,7 +89,7 @@ enum markdown_char_t {
 	MD_CHAR_AUTOLINK_EMAIL,
 	MD_CHAR_AUTOLINK_WWW,
 	MD_CHAR_SUPERSCRIPT,
-	MD_CHAR_DOLLAR,
+	MD_CHAR_DOLLAR
 };
 
 static char_trigger markdown_char_ptrs[] = {
@@ -908,7 +908,9 @@ char_codespan(struct buf *ob, struct sd_markdown *rndr, uint8_t *data, size_t of
 
 	/* real code span */
 	if (f_begin < f_end) {
-		struct buf work = { data + f_begin, f_end - f_begin, 0, 0 };
+		struct buf work = {0, 0, 0, 0};
+		work.data = data + f_begin;
+		work.size = f_end - f_begin;
 		if (!rndr->cb.codespan(ob, &work, rndr->opaque))
 			end = 0;
 	} else {
@@ -985,8 +987,10 @@ char_langle_tag(struct buf *ob, struct sd_markdown *rndr, uint8_t *data, size_t
 {
 	enum mkd_autolink altype = MKDA_NOT_AUTOLINK;
 	size_t end = tag_length(data, size, &altype);
-	struct buf work = { data, end, 0, 0 };
 	int ret = 0;
+	struct buf work = { 0, 0, 0, 0 };
+	work.data = data;
+	work.size = end;
 
 	if (end > 2) {
 		if (rndr->cb.autolink && altype != MKDA_NOT_AUTOLINK) {
@@ -1676,7 +1680,8 @@ parse_paragraph(struct buf *ob, struct sd_markdown *rndr, uint8_t *data, size_t
 {
 	size_t i = 0, end = 0;
 	int level = 0;
-	struct buf work = { data, 0, 0, 0 };
+	struct buf work = { 0, 0, 0, 0 };
+	work.data = data;
 
 	while (i < size) {
 		for (end = i + 1; end < size && data[end - 1] != '\n'; end++) /* empty */;
@@ -2143,7 +2148,8 @@ parse_htmlblock(struct buf *ob, struct sd_markdown *rndr, uint8_t *data, size_t
 {
 	size_t i, j = 0, tag_end;
 	const char *curtag = NULL;
-	struct buf work = { data, 0, 0, 0 };
+	struct buf work = { 0, 0, 0, 0 };
+	work.data = data;
 
 	/* identification of the opening tag */
 	if (size < 2 || data[0] != '<')
@@ -2703,7 +2709,7 @@ void
 sd_markdown_render(struct buf *ob, const uint8_t *document, size_t doc_size, struct sd_markdown *md)
 {
 #define MARKDOWN_GROW(x) ((x) + ((x) >> 1))
-	static const char UTF8_BOM[] = {0xEF, 0xBB, 0xBF};
+	static const uint8_t UTF8_BOM[] = {0xEF, 0xBB, 0xBF};
 
 	struct buf *text;
 	size_t beg, end;
